@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 145 $
+# Revision: $Rev: 180 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -339,6 +339,76 @@ class ListViewRecord(QListView):
             
             
 
+    def changeNumber(self, mode, number):
+        """called when the number of the current item needs be changed"""
+        
+        if (mode == "first"):
+            # get list of all indexes
+            indexList = []
+            for r in self.items.values():
+                indexList.append(int(r['number']))
+            indexList.sort()
+
+            # find first free index
+            index = 1
+            for i in indexList:
+                if (i < index): continue
+                elif (i == index): index += 1
+                else: break
+
+            # set index
+            self.log.info("Replacing number with first free index %d", index)
+            self.getCurrentRecord()['number'] = index
+            
+        elif (mode == "swap"):
+            self.log.info("Swapping number with record %d", number)
+            curr = self.getCurrentRecord()
+            other = filter(lambda a: a['number'] == number, self.items.values())
+            
+            if (len(other) > 1):
+                self.log.warning("Multiple record numbers %d (count=%d); swapping with all", number, len(other))
+            if (len(other) == 0):
+                self.log.warning("No record with number %d exist; not swapping", number)
+                
+            tmp = curr['number']
+            curr['number'] = number
+            for o in other: o['number'] = tmp
+                
+        elif (mode == "insert"):
+            self.log.info("Inserting record at number %d", number)
+
+            # get records that need re-indexing
+            shifts = filter(lambda a: a['number'] >= number, self.items.values())
+            # sort ascendingly; need only to increase indexes
+            # until a missing index is found
+            shifts.sort(lambda a,b: int(a['number']) -int(b['number']))
+            index = number
+            for r in shifts:
+                # stop when there's a missing index
+                if (r['number'] != index): break
+                # increase number
+                r['number'] += 1
+                index += 1
+
+            # set current item to the designated value
+            self.getCurrentRecord()['number'] = number
+                
+        elif (mode == "set"):
+            self.log.info("Setting record index to %d", number)
+            self.getCurrentRecord()['number'] = number
+            
+        else:
+            self.log.warning("Invalid mode in changing number: %s", mode)
+        
+        # update display
+        for obj in self.items.keys():
+            col = 0
+            for text in self.compileTitles(self.items[obj]):
+                obj.setText(col, text)
+                col += 1
+        self.sort()
+
+
 
     def focusFirst(self):
         """sets focus on the first record in the listview"""
