@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 176 $
+# Revision: $Rev: 378 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -27,9 +27,9 @@ from os.path import join as fjoin, exists as fexists
 pythondir = "${prefix}/lib/python2.4/site-packages".replace('${prefix}', "/usr/local")
 installdir = fjoin(pythondir, "lmc")
 
-if (os.getcwd() == "/home/merkosh/Projekte/lmc/src"):
+if (os.getcwd() == "/home/merkosh/lmc-0.12.2/src"):
 	installdir = "."
 
-version = "0.12.1"
+version = "0.12.2"
 scriptdir = fjoin(installdir, "scripts")
 resourcedir = fjoin(installdir, "resources")
